==> orthanc_1.2.0+dfsg.orig.tar.xz: Orthanc-1.2.0/OrthancServer/Search/HierarchicalMatcher.h <==
/**
 * Orthanc - A Lightweight, RESTful DICOM Store
 * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
 * Department, University Hospital of Liege, Belgium
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * In addition, as a special exception, the copyright holders of this
 * program give permission to link the code of its release with the
 * OpenSSL project's "OpenSSL" library (or with modified versions of it
 * that use the same license as the "OpenSSL" library), and distribute
 * the linked executables. You must obey the GNU General Public License
 * in all respects for all of the code used other than "OpenSSL". If you
 * modify file(s) with this exception, you may extend this exception to
 * your version of the file(s), but you are not obligated to do so. If
 * you do not wish to do so, delete this exception statement from your
 * version. If you delete this exception statement from all source files
 * in the program, then also delete it here.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 **/


#pragma once

#include "../../Core/DicomFormat/DicomMap.h"
#include "IFindConstraint.h"
#include "../ParsedDicomFile.h"

class DcmItem;

namespace Orthanc
{
  class HierarchicalMatcher : public boost::noncopyable
  {
  private:
    typedef std::map<DicomTag, IFindConstraint*>      Constraints;
    typedef std::map<DicomTag, HierarchicalMatcher*>  Sequences;

    Constraints  constraints_;
    Sequences    sequences_;

    void Setup(DcmItem& query,
               bool caseSensitivePN,
               Encoding encoding);

    HierarchicalMatcher(DcmItem& query,
                        bool caseSensitivePN,
                        Encoding encoding)
    {
      Setup(query, caseSensitivePN, encoding);
    }

    bool MatchInternal(DcmItem& dicom,
                       Encoding encoding) const;

    DcmDataset* ExtractInternal(DcmItem& dicom,
                                Encoding encoding) const;

  public:
    HierarchicalMatcher(ParsedDicomFile& query,
                        bool caseSensitivePN);

    ~HierarchicalMatcher();

    std::string Format(const std::string& prefix = "") const;

    bool Match(ParsedDicomFile& dicom) const;

    ParsedDicomFile* Extract(ParsedDicomFile& dicom) const;
  };
}

==> orthanc_1.3.0+dfsg.orig.tar.xz: Orthanc-1.3.0/OrthancServer/Search/HierarchicalMatcher.h <==
/**
 * Orthanc - A Lightweight, RESTful DICOM Store
 * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
 * Department, University Hospital of Liege, Belgium
 * Copyright (C) 2017 Osimis, Belgium
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * In addition, as a special exception, the copyright holders of this
 * program give permission to link the code of its release with the
 * OpenSSL project's "OpenSSL" library (or with modified versions of it
 * that use the same license as the "OpenSSL" library), and distribute
 * the linked executables. You must obey the GNU General Public License
 * in all respects for all of the code used other than "OpenSSL". If you
 * modify file(s) with this exception, you may extend this exception to
 * your version of the file(s), but you are not obligated to do so. If
 * you do not wish to do so, delete this exception statement from your
 * version. If you delete this exception statement from all source files
 * in the program, then also delete it here.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 **/


#pragma once

#include "../../Core/DicomFormat/DicomMap.h"
#include "IFindConstraint.h"
#include "../ParsedDicomFile.h"

class DcmItem;

namespace Orthanc
{
  class HierarchicalMatcher : public boost::noncopyable
  {
  private:
    typedef std::map<DicomTag, IFindConstraint*>      Constraints;
    typedef std::map<DicomTag, HierarchicalMatcher*>  Sequences;

    Constraints  constraints_;
    Sequences    sequences_;

    void Setup(DcmItem& query,
               bool caseSensitivePN,
               Encoding encoding);

    HierarchicalMatcher(DcmItem& query,
                        bool caseSensitivePN,
                        Encoding encoding)
    {
      Setup(query, caseSensitivePN, encoding);
    }

    bool MatchInternal(DcmItem& dicom,
                       Encoding encoding) const;

    DcmDataset* ExtractInternal(DcmItem& dicom,
                                Encoding encoding) const;

  public:
    HierarchicalMatcher(ParsedDicomFile& query);

    ~HierarchicalMatcher();

    std::string Format(const std::string& prefix = "") const;

    bool Match(ParsedDicomFile& dicom) const;

    ParsedDicomFile* Extract(ParsedDicomFile& dicom) const;
  };
}
